@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cae.cpp,v 1.104 2008/08/18 16:09:07 fredg Exp $
+//      $Id: cae.cpp,v 1.104.2.1 2009/04/08 15:53:24 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -366,7 +366,7 @@ MainObject::MainObject(QObject *parent,const char *name)
     if (r) {
       result = r;
     }
-    mlockall(MCL_FUTURE);
+    mlockall(MCL_CURRENT|MCL_FUTURE);
     if (result){
           LogLine(RDConfig::LogWarning,QString().
 		  sprintf("Unable to set realtime scheduling: %s",
@@ -1791,6 +1791,8 @@ void MainObject::BroadcastCommand(const char *command)
 
 void MainObject::EchoCommand(int ch,const char *command)
 {
+//    LogLine(RDConfig::LogErr,QString().sprintf("EchoCommand(%s)\n",
+//					       (const char *)command));
   if(socket[ch]->state()==QSocket::Connection) {
 #ifdef PRINT_COMMANDS
     printf("CAE: Connection %d sending %s\n",ch,command);
