@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cae_jack.cpp,v 1.43 2007/09/14 14:06:23 fredg Exp $
+//      $Id: cae_jack.cpp,v 1.50 2008/07/18 20:06:10 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,8 +26,10 @@
 
 #include <qsignalmapper.h>
 
+#include <rd.h>
 #include <rdringbuffer.h>
 #include <rdprofile.h>
+#include <rdmeteraverage.h>
 
 #include <cae.h>
 
@@ -35,8 +37,11 @@
 //
 // Callback Variables
 //
-volatile jack_default_audio_sample_t jack_input_meter[RD_MAX_PORTS][2];
-volatile jack_default_audio_sample_t jack_output_meter[RD_MAX_PORTS][2];
+jack_client_t *jack_client;
+RDMeterAverage *jack_input_meter[RD_MAX_PORTS][2];
+RDMeterAverage *jack_output_meter[RD_MAX_PORTS][2];
+//volatile jack_default_audio_sample_t jack_input_meter[RD_MAX_PORTS][2];
+//volatile jack_default_audio_sample_t jack_output_meter[RD_MAX_PORTS][2];
 volatile jack_default_audio_sample_t 
   jack_input_volume[RD_MAX_PORTS];
 volatile jack_default_audio_sample_t 
@@ -238,7 +243,7 @@ int JackProcess(jack_nframes_t nframes, void *arg)
 	}
       }
       double ratio=(double)jack_output_sample_rate[i]/(double)jack_sample_rate;
-      jack_output_pos[i]+=((double)n*ratio)+0.5;
+      jack_output_pos[i]+=(int)(((double)n*ratio)+0.5);
     }
   }
 
@@ -274,8 +279,8 @@ int JackProcess(jack_nframes_t nframes, void *arg)
             break;
       }
     } // for nframes
-    jack_input_meter[i][0]=in_meter[0];
-    jack_input_meter[i][1]=in_meter[1];
+    jack_input_meter[i][0]->addValue(in_meter[0]);
+    jack_input_meter[i][1]->addValue(in_meter[1]);
 
     // output meters
     for(int j=0;j<2;j++) {
@@ -284,7 +289,7 @@ int JackProcess(jack_nframes_t nframes, void *arg)
 	if(jack_output_buffer[i][j][k]>out_meter[j]) 
 	  out_meter[j]=jack_output_buffer[i][j][k];
       }
-      jack_output_meter[i][j]=out_meter[j];
+      jack_output_meter[i][j]->addValue(out_meter[j]);
     }
 
   } // for RD_MAX_PORTS
@@ -313,14 +318,16 @@ void JackShutdown(void *arg)
 
 void JackInitCallback()
 {
+  int avg_periods=(int)(330.0*jack_get_sample_rate(jack_client)/
+			(1000.0*jack_get_buffer_size(jack_client)));
   for(int i=0;i<RD_MAX_PORTS;i++) {
     jack_recording[i]=false;
     jack_ready[i]=false;
     jack_input_volume[i]=1.0;
     jack_input_vox[i]=0.0;
     for(int j=0;j<2;j++) {
-      jack_input_meter[i][j]=0.0;
-      jack_output_meter[i][j]=0.0;
+      jack_input_meter[i][j]=new RDMeterAverage(avg_periods);
+      jack_output_meter[i][j]=new RDMeterAverage(avg_periods);
       jack_input_buffer[i][j]=NULL;
       jack_output_buffer[i][j]=NULL;
     }
@@ -398,7 +405,7 @@ void MainObject::jackInit(RDStation *station)
     }
   }
   if(jack_card==RD_MAX_CARDS) {
-    LogLine("no more RD cards available");
+    LogLine(RDConfig::LogInfo,"no more RD cards available");
     return;
   }
   QString name=QString().sprintf("rivendell_%d",jack_card);
@@ -409,7 +416,7 @@ void MainObject::jackInit(RDStation *station)
 
   if((jack_client=jack_client_new((const char *)name))==0) {
     fprintf (stderr, "no connection to JACK server\n");
-    LogLine("no connection to JACK server");
+    LogLine(RDConfig::LogNotice,"no connection to JACK server");
     return;
   }
   jack_connected=true;
@@ -535,10 +542,17 @@ bool MainObject::jackLoadPlayback(int card,QString wavename,int *stream)
 {
 #ifdef JACK
   if((*stream=GetJackOutputStream())<0) {
+    LogLine(RDConfig::LogErr,QString().sprintf(
+            "Error: jackLoadPlayback(%s)   GetJackOutputStream():%d <0",
+            (const char *) wavename,
+            *stream) );
     return false;
   }
   jack_play_wave[*stream]=new RDWaveFile(wavename);
   if(!jack_play_wave[*stream]->openWave()) {
+    LogLine(RDConfig::LogNotice,QString().sprintf(
+            "Error: jackLoadPlayback(%s)   openWave() failed to open file",
+            (const char *) wavename) );
     delete jack_play_wave[*stream];
     jack_play_wave[*stream]=NULL;
     FreeJackOutputStream(*stream);
@@ -547,6 +561,11 @@ bool MainObject::jackLoadPlayback(int card,QString wavename,int *stream)
   }
   if((jack_play_wave[*stream]->getFormatTag()!=WAVE_FORMAT_PCM)||
      (jack_play_wave[*stream]->getBitsPerSample()!=16)) {
+    LogLine(RDConfig::LogNotice,QString().sprintf(
+            "Error: jackLoadPlayback(%s)   getFormatTag()%d || getBistsPerSample()%d failed",
+            (const char *) wavename,
+            jack_play_wave[*stream]->getFormatTag(),
+            jack_play_wave[*stream]->getBitsPerSample() ));
     delete jack_play_wave[*stream];
     jack_play_wave[*stream]=NULL;
     FreeJackOutputStream(*stream);
@@ -570,6 +589,9 @@ bool MainObject::jackLoadPlayback(int card,QString wavename,int *stream)
 bool MainObject::jackUnloadPlayback(int card,int stream)
 {
 #ifdef JACK
+  if ((stream <0) || (stream >= RD_MAX_STREAMS)){
+    return false;
+  }
   if(jack_play_ring[stream]==NULL) {
     return false;
   }
@@ -588,6 +610,9 @@ bool MainObject::jackUnloadPlayback(int card,int stream)
 bool MainObject::jackPlaybackPosition(int card,int stream,unsigned pos)
 {
 #ifdef JACK
+  if ((stream <0) || (stream >= RD_MAX_STREAMS)){
+    return false;
+  }
   if(jack_playing[stream]) {
   }
   jack_eof[stream]=false;
@@ -615,7 +640,9 @@ bool MainObject::jackPlay(int card,int stream,int length,int speed,bool pitch,
 			 bool rates)
 {
 #ifdef JACK
-  if((jack_play_ring[stream]==NULL)||jack_playing[stream]||(speed!=1000)) {
+  if((stream <0) || (stream >= RD_MAX_STREAMS) || 
+     (jack_play_ring[stream]==NULL)||jack_playing[stream]||
+     (speed!=RD_TIMESCALE_DIVISOR)) {
     return false;
   }
   jack_playing[stream]=true;
@@ -633,7 +660,8 @@ bool MainObject::jackPlay(int card,int stream,int length,int speed,bool pitch,
 bool MainObject::jackStopPlayback(int card,int stream)
 {
 #ifdef JACK
-  if((jack_play_ring[stream]==NULL)||(!jack_playing[stream])) {
+  if((stream <0) || (stream>=RD_MAX_STREAMS) || 
+     (jack_play_ring[stream]==NULL)||(!jack_playing[stream])) {
     return false;
   }
   jack_playing[stream]=false;
@@ -659,6 +687,9 @@ bool MainObject::jackLoadRecord(int card,int stream,int coding,int chans,
 			       int samprate,int bitrate,QString wavename)
 {
 #ifdef JACK
+  if ((stream <0) || (stream >=RD_MAX_PORTS)){
+    return false;
+  }
   jack_record_wave[stream]=new RDWaveFile(wavename);
   jack_record_wave[stream]->setFormatTag(WAVE_FORMAT_PCM);
   jack_record_wave[stream]->setChannels(chans);
@@ -672,11 +703,6 @@ bool MainObject::jackLoadRecord(int card,int stream,int coding,int chans,
     return false;
   }
   chown((const char *)wavename,rd_config->uid(),rd_config->gid());
-  if (stream >= RD_MAX_PORTS) { // verify that stream is < RD_MAX_PORTS for jack_input_channels[], jack_record_ring[] and others
-    delete jack_record_wave[stream];
-    jack_record_wave[stream]=NULL;
-    return false;
-  }
   jack_input_channels[stream]=chans; 
   jack_record_ring[stream]=new RDRingBuffer(RINGBUFFER_SIZE);
   jack_record_ring[stream]->reset();
@@ -691,6 +717,9 @@ bool MainObject::jackLoadRecord(int card,int stream,int coding,int chans,
 bool MainObject::jackUnloadRecord(int card,int stream)
 {
 #ifdef JACK
+  if ((stream <0) || (stream >= RD_MAX_PORTS)){
+    return false;
+  }
   jack_recording[stream]=false;
   jack_ready[stream]=false;
   EmptyJackInputStream(stream);
@@ -709,6 +738,9 @@ bool MainObject::jackUnloadRecord(int card,int stream)
 bool MainObject::jackRecord(int card,int stream,int length,int thres)
 {
 #ifdef JACK
+  if ((stream <0) || (stream >= RD_MAX_PORTS)){
+    return false;
+  }
   if(!jack_ready[stream]) {
     return false;
   }
@@ -729,6 +761,9 @@ bool MainObject::jackRecord(int card,int stream,int length,int thres)
 bool MainObject::jackStopRecord(int card,int stream)
 {
 #ifdef JACK
+  if ((stream <0) || (stream >= RD_MAX_PORTS)){
+    return false;
+  }
   if(!jack_recording[stream]) {
     return false;
   }
@@ -743,6 +778,9 @@ bool MainObject::jackStopRecord(int card,int stream)
 bool MainObject::jackSetInputVolume(int card,int stream,int level)
 {
 #ifdef JACK
+  if ((stream <0) || (stream >= RD_MAX_STREAMS)){
+    return false;
+  }
   if(level>-10000) {
     jack_input_volume[stream]=
       (jack_default_audio_sample_t)pow10((double)level/2000.0);
@@ -762,6 +800,10 @@ bool MainObject::jackSetInputVolume(int card,int stream,int level)
 bool MainObject::jackSetOutputVolume(int card,int stream,int port,int level)
 {
 #ifdef JACK
+  if ((stream <0) ||(stream >= RD_MAX_STREAMS) || 
+      (port <0) || (port >= RD_MAX_PORTS)){
+    return false;
+  }
   if(level>-10000) {
     jack_output_volume[port][stream]=
       (jack_default_audio_sample_t)pow10((double)level/2000.0);
@@ -783,7 +825,10 @@ bool MainObject::jackFadeOutputVolume(int card,int stream,int port,int level,
 {
 #ifdef JACK
   int diff;
-
+  if ((stream <0) ||(stream >= RD_MAX_STREAMS) || 
+      (port <0) || (port >= RD_MAX_PORTS)){
+    return false;
+  }
   if(jack_fade_timer[stream]->isActive()) {
     jack_fade_timer[stream]->stop();
   }
@@ -797,8 +842,8 @@ bool MainObject::jackFadeOutputVolume(int card,int stream,int port,int level,
   }
   jack_fade_volume_db[stream]=level;
   jack_fade_port[stream]=port;
-  jack_fade_increment[stream]=diff*JACK_FADE_INTERVAL/length;
-  jack_fade_timer[stream]->start(JACK_FADE_INTERVAL);
+  jack_fade_increment[stream]=diff*RD_JACK_FADE_INTERVAL/length;
+  jack_fade_timer[stream]->start(RD_JACK_FADE_INTERVAL);
   return true;
 #else
   return false;
@@ -881,9 +926,11 @@ bool MainObject::jackGetInputMeters(int card,int port,short levels[2])
 {
 #ifdef JACK
   jack_default_audio_sample_t meter;
-
+  if ((port <0) || (port >= RD_MAX_PORTS)){
+    return false;
+  }
   for(int i=0;i<2;i++) {
-    meter=jack_input_meter[port][i];
+    meter=jack_input_meter[port][i]->average();
     if(meter==0.0) {
       levels[i]=-10000;
     }
@@ -905,9 +952,12 @@ bool MainObject::jackGetOutputMeters(int card,int port,short levels[2])
 {
 #ifdef JACK
   jack_default_audio_sample_t meter;
+  if ((port <0) || (port >= RD_MAX_PORTS)){
+    return false;
+  }
 
   for(int i=0;i<2;i++) {
-    meter=jack_output_meter[port][i];
+    meter=jack_output_meter[port][i]->average();
     if(meter==0.0) {
       levels[i]=-10000;
     }
@@ -929,17 +979,21 @@ void MainObject::jackGetOutputPosition(int card,unsigned *pos)
 {
 #ifdef JACK
   for(int i=0;i<RD_MAX_STREAMS;i++) {
-    pos[i]=(((unsigned long long)jack_offset[i]+jack_output_pos[i])*1000)/
-	    jack_sample_rate;
+//    pos[i]=(((unsigned long long)jack_offset[i]+jack_output_pos[i])*1000)/
+//	    jack_sample_rate;
+    pos[i]=((unsigned long long)jack_offset[i]+jack_output_pos[i]);
   }
 #endif  // JACK
 }
 
-
 bool MainObject::jackSetPassthroughLevel(int card,int in_port,int out_port,
 					int level)
 {
 #ifdef JACK
+  if ((in_port <0) || (in_port >= RD_MAX_PORTS) || 
+      (out_port <0) || (out_port >= RD_MAX_PORTS)){
+    return false;
+  }
   if(level>-10000) {
     jack_passthrough_volume[in_port][out_port]=
       (jack_default_audio_sample_t)pow10((double)level/2000.0);
@@ -975,6 +1029,9 @@ int MainObject::GetJackOutputStream()
 void MainObject::FreeJackOutputStream(int stream)
 {
 #ifdef JACK
+  if ((stream <0) || (stream >= RD_MAX_STREAMS)){
+    return;
+  }
   delete jack_play_ring[stream];
   jack_play_ring[stream]=NULL;
 #else
@@ -986,6 +1043,9 @@ void MainObject::FreeJackOutputStream(int stream)
 void MainObject::EmptyJackInputStream(int stream)
 {
 #ifdef JACK
+  if ((stream <0) || (stream >= RD_MAX_STREAMS)){
+    return;
+  }
   int n=jack_record_ring[stream]->
     read((char *)jack_sample_buffer,RINGBUFFER_SIZE)/
     sizeof(jack_default_audio_sample_t);
@@ -1023,6 +1083,9 @@ void MainObject::EmptyJackInputStream(int stream)
 void MainObject::FillJackOutputStream(int stream)
 {
 #ifdef JACK
+  if ((stream <0) || (stream >= RD_MAX_STREAMS)){
+    return;
+  }
   int free=
     jack_play_ring[stream]->writeSpace()/sizeof(jack_default_audio_sample_t)-1;
   if((free<=0)||(jack_eof[stream]==true)) {
@@ -1098,8 +1161,9 @@ void MainObject::JackSessionSetup()
   QString dest=profile->stringValue("JackSession",dest_tag,"",&dest_ok);
   while(src_ok&&dest_ok) {
     if(jack_connect(jack_client,(const char *)src,(const char *)dest)!=0) {
-      LogLine(QString().sprintf("unable to connect %s to %s",
-				(const char *)src,(const char *)dest));
+      LogLine(RDConfig::LogNotice,QString().
+	      sprintf("unable to connect %s to %s",
+		      (const char *)src,(const char *)dest));
     }
     count++;
     src_tag=QString().sprintf("Source%d",count+1);
