@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdmatrix.h,v 1.24 2008/09/30 18:19:39 fredg Exp $
+//      $Id: rdmatrix.h,v 1.24.2.1 2009/02/10 16:19:32 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -67,6 +67,10 @@ class RDMatrix
   void setUsername(RDMatrix::Role role,const QString &name) const;
   QString password(RDMatrix::Role role) const;
   void setPassword(RDMatrix::Role role,const QString &passwd) const;
+  unsigned startCart(RDMatrix::Role role) const;
+  void setStartCart(RDMatrix::Role role,unsigned cartnum) const;
+  unsigned stopCart(RDMatrix::Role role) const;
+  void setStopCart(RDMatrix::Role role,unsigned cartnum) const;
   int port(RDMatrix::Role role) const;
   void setPort(RDMatrix::Role role,int port) const;
   int inputs() const;
@@ -92,6 +96,7 @@ class RDMatrix
   QVariant GetRow(const QString &param) const;
   void SetRow(const QString &param,const QString &value) const;
   void SetRow(const QString &param,int value) const;
+  void SetRow(const QString &param,unsigned value) const;
   QString mx_station;
   int mx_number;
 };
