@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: add_matrix.cpp,v 1.22 2007/09/14 14:06:26 fredg Exp $
+//      $Id: add_matrix.cpp,v 1.25 2008/03/19 02:43:23 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,10 +31,10 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
 
 #include <rd.h>
 #include <rdmatrix.h>
+#include <rddb.h>
 
 #include <edit_user.h>
 #include <add_matrix.h>
@@ -99,6 +99,8 @@ AddMatrix::AddMatrix(QString station,QWidget *parent,const char *name)
   add_type_box->insertItem(tr("BroadcastTools SS16.4"));
   add_type_box->insertItem(tr("StarGuide III"));
   add_type_box->insertItem(tr("BroadcastTools SS4.2"));
+  add_type_box->insertItem(tr("Axia LiveWire"));
+  add_type_box->insertItem(tr("Quartz Type 1"));
   label=new QLabel(add_type_box,tr("&Switcher Type:"),this,
 		   "matrix_label");
   label->setGeometry(10,36,150,19);
@@ -158,7 +160,7 @@ void AddMatrix::okData()
                                  where STATION_NAME=\"%s\" && MATRIX=%d",
 				(const char *)add_station,
 				add_matrix_box->value());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     delete q;
     QMessageBox::warning(this,tr("Invalid Matrix"),
@@ -258,6 +260,13 @@ void AddMatrix::okData()
 	gpos=8;
 	break;
 
+      case RDMatrix::LiveWire:
+	inputs=0;
+	outputs=0;
+	gpis=0;
+	gpos=0;
+	break;
+
       default:
 	inputs=0;
 	outputs=0;
@@ -284,7 +293,7 @@ void AddMatrix::okData()
 			outputs,
 			gpis,
 			gpos);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   done(add_matrix_box->value());
 }
@@ -303,7 +312,7 @@ int AddMatrix::GetNextMatrix()
   QString sql=QString().sprintf("select MATRIX from MATRICES\
                                  where STATION_NAME=\"%s\" order by MATRIX",
 				(const char *)add_station);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
     if(n!=q->value(0).toInt()) {
       delete q;
