@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_switchevent.cpp,v 1.20 2007/09/14 14:06:50 fredg Exp $
+//      $Id: edit_switchevent.cpp,v 1.22 2007/12/31 18:49:10 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,8 +29,8 @@
 #include <qevent.h>
 #include <qmessagebox.h>
 #include <qcheckbox.h>
-#include <qsqldatabase.h>
 
+#include <rddb.h>
 #include <rd.h>
 #include <rdcart_dialog.h>
 #include <rdcut_path.h>
@@ -40,12 +40,11 @@
 
 
 EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,
-				 QString *filter,
 				 QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString temp;
   edit_matrix=NULL;
   edit_added_events=adds;
@@ -68,7 +67,6 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,
   QFont day_font=QFont("Helvetica",10,QFont::Normal);
   day_font.setPixelSize(10);
 
-  edit_filter=filter;
   edit_deck=NULL;
 
   setCaption(tr("Edit Switcher Event"));
@@ -302,7 +300,7 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,
   // Populate Data
   //
   edit_active_button->setChecked(edit_recording->isActive());
-  q=new QSqlQuery("select NAME from STATIONS where NAME!=\"DEFAULT\"");
+  q=new RDSqlQuery("select NAME from STATIONS where NAME!=\"DEFAULT\"");
   while(q->next()) {
     edit_station_box->insertItem(q->value(0).toString());
     if(edit_recording->station()==q->value(0).toString()) {
@@ -361,7 +359,7 @@ void EditSwitchEvent::activateStationData(const QString &str)
                                  (OUTPUTS>0) order by NAME",
 				(const char *)str);
   edit_matrix_box->clear();
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   int matrix=edit_recording->channel();
   while(q->next()) {
     edit_matrix_box->insertItem(q->value(0).toString());
@@ -400,7 +398,7 @@ void EditSwitchEvent::activateMatrixData(const QString &str)
     edit_input_spin->setDisabled(true);
   }
   edit_input_spin->setValue(input);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
     edit_input_box->insertItem(q->value(0).toString());
     if(q->value(1).toInt()==input) {
@@ -425,7 +423,7 @@ void EditSwitchEvent::activateMatrixData(const QString &str)
     edit_output_spin->setDisabled(true);
   }
   edit_output_spin->setValue(output);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     edit_output_box->insertItem(q->value(0).toString());
     if(q->value(1).toInt()==output) {
@@ -563,7 +561,7 @@ int EditSwitchEvent::GetMatrix()
                                 (INPUTS>0)&&(OUTPUTS>0)",
 				(const char *)edit_station_box->currentText(),
 				(const char *)edit_matrix_box->currentText());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     matrix=q->value(0).toInt();
   }
@@ -582,7 +580,7 @@ int EditSwitchEvent::GetSource()
 				(const char *)edit_station_box->currentText(),
 				GetMatrix(),
 				(const char *)edit_input_box->currentText());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     input=q->value(0).toInt();
   }
@@ -601,7 +599,7 @@ int EditSwitchEvent::GetDestination()
 				(const char *)edit_station_box->currentText(),
 				GetMatrix(),
 				(const char *)edit_output_box->currentText());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     output=q->value(0).toInt();
   }
@@ -647,7 +645,7 @@ bool EditSwitchEvent::CheckEvent(bool include_myself)
   if(!include_myself) {
     sql+=QString().sprintf("&&(ID!=%d)",edit_recording->id());
   }
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   bool res=!q->first();
   delete q;
 
