@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcatchd.cpp,v 1.130.2.2 2008/11/29 15:48:11 fredg Exp $
+//      $Id: rdcatchd.cpp,v 1.130.2.4 2009/03/31 11:21:01 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -168,6 +168,9 @@ MainObject::MainObject(QObject *parent,const char *name)
     catch_playout_handle[i]=-1;
     catch_monitor_port[i]=-1;
     catch_monitor_state[i]=false;
+    catch_record_pending_cartnum[i]=0;
+    catch_record_pending_cutnum[i]=0;
+    catch_record_pending_maxlen[i]=0;
   }
 
   //
@@ -891,6 +894,7 @@ void MainObject::recordUnloadedData(int card,int stream)
     LogLine(RDConfig::LogDebug,QString().
 	    sprintf("invalid record event:  Id: %d",
 		    catch_record_id[deck-1]));
+    RunRmlRecordingCache(deck);
     return;
   }
 
@@ -944,6 +948,9 @@ void MainObject::recordUnloadedData(int card,int stream)
      catch_events[event].allowMultipleRecordings()) {
     engineData(catch_events[event].id());
   }
+  else {
+    RunRmlRecordingCache(deck);
+  }
 }
 
 
@@ -2900,6 +2907,7 @@ void MainObject::CheckInPodcast(CatchEvent *e)
                          AUDIO_LENGTH=%u,\
                          AUDIO_TIME=%u,\
                          SHELF_LIFE=%u,\
+                         EFFECTIVE_DATETIME=now(),\
                          ORIGIN_DATETIME=now()",
 			  e->feedId(),
 			  status,
@@ -3166,6 +3174,46 @@ unsigned MainObject::GetNextDynamicId()
 }
 
 
+void MainObject::RunRmlRecordingCache(int chan)
+{
+  if(catch_record_pending_cartnum[chan-1]==0) {
+    return;
+  }
+  StartRmlRecording(chan,catch_record_pending_cartnum[chan-1],
+		    catch_record_pending_cutnum[chan-1],
+		    catch_record_pending_maxlen[chan-1]);
+  catch_record_pending_cartnum[chan-1]=0;
+}
+
+
+void MainObject::StartRmlRecording(int chan,int cartnum,int cutnum,int maxlen)
+{
+  RDDeck *deck=new RDDeck(catch_config->stationName(),chan);
+  RDCut *cut=new RDCut(cartnum,cutnum);
+  QDateTime dt=QDateTime(QDate::currentDate(),QTime::currentTime());
+  catch_events.push_back(CatchEvent());
+  catch_events.back().setId(GetNextDynamicId());
+  catch_events.back().setIsActive(true);
+  catch_events.back().setOneShot(true);
+  catch_events.back().setType(RDRecording::Recording);
+  catch_events.back().setChannel(chan);
+  catch_events.back().setCutName(cut->cutName());
+  catch_events.back().setDayOfWeek(dt.date().dayOfWeek(),true);
+  catch_events.back().setStartTime(dt.time());
+  catch_events.back().setEndType(RDRecording::LengthEnd);
+  catch_events.back().setLength(maxlen);
+  catch_events.back().
+    setFormat((RDCae::AudioCoding)deck->defaultFormat());
+  catch_events.back().setChannels(deck->defaultChannels());
+  catch_events.back().setSampleRate(deck->defaultSamprate());
+  catch_events.back().setBitrate(deck->defaultBitrate());
+  catch_events.back().setNormalizeLevel(deck->defaultThreshold());
+  StartRecording(catch_events.size()-1);
+  delete cut;
+  delete deck;
+}
+
+
 int main(int argc,char *argv[])
 {
   QApplication a(argc,argv,false);
