@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: disk_ripper.cpp,v 1.19 2007/09/14 14:06:55 fredg Exp $
+//      $Id: disk_ripper.cpp,v 1.23.2.2 2009/04/03 11:44:10 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,6 +33,7 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 
+#include <rddb.h>
 #include <rd.h>
 #include <rdconf.h>
 #include <rdwavefile.h>
@@ -278,9 +279,10 @@ DiskRipper::DiskRipper(QString *filter,QString *group,
   //
   // Rip Track Button
   //
-  rip_rip_button=new QPushButton(tr("&Rip\nDisk"),this,"rip_rip_button");
+  rip_rip_button=new QPushButton(tr("&Rip\nDisc"),this,"rip_rip_button");
   rip_rip_button->setFont(button_font);
   connect(rip_rip_button,SIGNAL(clicked()),this,SLOT(ripDiskButtonData()));
+  rip_rip_button->setDisabled(true);
 
   //
   // Close Button
@@ -405,9 +407,9 @@ void DiskRipper::setCutButtonData()
     return;
   }
   QString cutname=rip_cutnames[item->text(0).toUInt()-1];
-  RDCutDialog *dialog=new RDCutDialog(&cutname,rip_filter_text,rip_group_text,
-				      lib_user->name(),true,true,true,
-				      this,"cut_dialog");
+  RDCutDialog *dialog=new RDCutDialog(&cutname,rdstation_conf,rip_filter_text,
+				      rip_group_text,lib_user->name(),true,
+				      true,true,this,"cut_dialog");
   if(dialog->exec()==0) {
     if(cutname.isEmpty()) {
       rip_cutnames[item->text(0).toUInt()-1]="";
@@ -421,21 +423,18 @@ void DiskRipper::setCutButtonData()
 	  return;
 	}
       }
-      if(QFile::exists(QString().sprintf("%s/%s.%s",
-					 RD_AUDIO_ROOT,
-					 (const char *)cutname,
-					 RD_AUDIO_EXTENSION))) {
+      if(QFile::exists(RDCut::pathName(cutname))){
 	switch(QMessageBox::warning(this,tr("Cut Exists"),
 				    tr("A recording already exists.\nDo you want to overwrite it?"),
 				    QMessageBox::Yes,
 				    QMessageBox::No)) {
-	    case QMessageBox::No:
-	    case QMessageBox::NoButton:
-	      delete dialog;
-	      return;
-
-	    default:
-	      break;
+	case QMessageBox::No:
+	case QMessageBox::NoButton:
+	  delete dialog;
+	  return;
+	  
+	default:
+	  break;
 	}
       }
       if(cut_clipboard!=NULL) {
@@ -444,12 +443,12 @@ void DiskRipper::setCutButtonData()
 				      tr("Ripping this cut will also empty the clipboard.\nDo you still want to proceed?"),
 				      QMessageBox::Yes,
 				      QMessageBox::No)) {
-	      case QMessageBox::No:
-	      case QMessageBox::NoButton:
-		return;
-
-	      default:
-		break;
+	  case QMessageBox::No:
+	  case QMessageBox::NoButton:
+	    return;
+	    
+	  default:
+	    break;
 	  }
 	  delete cut_clipboard;
 	  cut_clipboard=NULL;
@@ -465,6 +464,16 @@ void DiskRipper::setCutButtonData()
     }
   }
   delete dialog;
+
+  bool track_selected=false;
+  item=rip_track_list->firstChild();
+  while(item!=NULL) {
+    if(!item->text(5).isEmpty()) {
+      track_selected=true;
+    }
+    item=item->nextSibling();
+  }
+  rip_rip_button->setEnabled(track_selected);
 }
 
 
@@ -494,6 +503,7 @@ void DiskRipper::setAllButtonData()
     cart_num++;
     item=item->nextSibling();
   }
+  rip_rip_button->setEnabled(true);
 }
 
 
@@ -644,10 +654,12 @@ void DiskRipper::barTimerData()
 	}
 	item=item->nextSibling();
       }
+      rip_cdrom->eject();
       QMessageBox::information(this,tr("Rip Complete"),
 			       tr("Rip complete!"));
     }
     else {
+      rip_cdrom->eject();
       if(rip_rip_aborted) {
 	QMessageBox::information(this,tr("Rip Aborted"),
 				 tr("The rip has been aborted."));
@@ -662,7 +674,6 @@ Please check your ripper configuration and try again."));
     rip_eject_button->setEnabled(true);
     rip_play_button->setEnabled(true);
     rip_stop_button->setEnabled(true);
-    rip_rip_button->setEnabled(true);
     rip_setcut_button->setEnabled(true);
     rip_setall_button->setEnabled(true);
     rip_close_button->setEnabled(true);
@@ -759,7 +770,7 @@ void DiskRipper::RipTrack(int track,QString cutname,QString title)
   unsigned cartnum=cutname.left(6).toUInt();
   QString sql=QString().sprintf("select NUMBER from CART where NUMBER=%u",
 				cartnum);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(!q->first()) {  // Create Cart/cut entries
     delete q;
     sql=QString().sprintf("insert into CART set \
@@ -767,21 +778,19 @@ void DiskRipper::RipTrack(int track,QString cutname,QString title)
                            TITLE=\"[New Cart %06u]\",CUT_QUANTITY=1",
 			  cartnum,RDCart::Audio,
 			  (const char *)(*rip_group_text),cartnum);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     delete q;
     sql=QString().sprintf("insert into CUTS set\
                            CUT_NAME=\"%s\",CART_NUMBER=%u,\
                            DESCRIPTION=\"Cut 001\"",
 			  (const char *)cutname,cartnum);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
   }
   delete q;
   
   rip_done=false;
   rip_rip_aborted=false;
-  rip_wavefile=QString().sprintf("%s/%s.%s",RD_AUDIO_ROOT,
-				 (const char *)cutname,
-				 RD_AUDIO_EXTENSION);
+  rip_wavefile=RDCut::pathName(cutname); 
   rip_track_number=track;
   rip_title=title;
   rip_cutname=cutname;
@@ -935,6 +944,7 @@ void DiskRipper::AutoTrim()
     cut->setEndPoint((int)(1000.0*(double)point/
 			     (double)wave->getSamplesPerSec()));
   }
+  cut->setLength(cut->endPoint()-cut->startPoint());
   delete wave;
   delete cut;
 }
