@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: voice_tracker.h,v 1.43 2007/04/17 09:53:01 stgabriel Exp $
+//      $Id: voice_tracker.h,v 1.46 2007/12/29 18:16:11 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -36,10 +36,8 @@
 #include <qcursor.h>
 #include <qpopupmenu.h>
 
-#include <rtransportbutton.h>
-#include <rstereometer.h>
-#include <rwavefile.h>
-
+#include <rdtransportbutton.h>
+#include <rdstereometer.h>
 #include <rdcart.h>
 #include <rdcut.h>
 #include <rdgroup.h>
@@ -90,6 +88,7 @@ class VoiceTracker : public QDialog
   void updateMenuData();
   void hideMenuData();
   virtual void keyPressEvent(QKeyEvent *e);
+  virtual void keyReleaseEvent(QKeyEvent *e);
   virtual void wheelEvent(QWheelEvent *e);
   void playData();
   void stopData();
@@ -169,10 +168,10 @@ class VoiceTracker : public QDialog
   void CheckChanges();
   void PushSegues();
   void PopSegues();
-  RStereoMeter *track_meter;
+  RDStereoMeter *track_meter;
   QTimer *track_meter_timer;
-  RTransportButton *track_play_button;
-  RTransportButton *track_stop_button;
+  RDTransportButton *track_play_button;
+  RDTransportButton *track_stop_button;
   QPushButton *track_track1_button;
   QPushButton *track_record_button;
   QPushButton *track_track2_button;
@@ -202,6 +201,7 @@ class VoiceTracker : public QDialog
   QPalette edit_time_remaining_palette[2];
   QPixmap *edit_wave_map[3];
   QString edit_wave_name[3];
+  RDWavePainter *wpg[3];
   //int edit_wave_pos[3];
   int edit_scroll_pos[3];
   int edit_wave_origin[3];
@@ -283,6 +283,7 @@ class VoiceTracker : public QDialog
   QRect *track_target_rect[VoiceTracker::TargetSize];
   int track_target_track[VoiceTracker::TargetSize];
   VoiceTracker::Target track_current_target;
+  bool edit_shift_pressed;
 };
 
 
