@@ -178,6 +178,10 @@ Do you want to save?</source>
 Rules</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Remarks</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -492,11 +496,11 @@ Do you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Overlap</source>
+        <source>REMARKS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>OVERLAP</source>
+        <source>Len:</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -678,10 +682,6 @@ Do you want to save?</source>
 </context>
 <context>
     <name>GenerateLog</name>
-    <message>
-        <source>Generate Log</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Generating Log...</source>
         <translation type="unfinished"></translation>
@@ -784,6 +784,10 @@ will remove this data.  Remerge?</source>
         <source>Import Data</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Generate Log - User: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImportListView</name>
@@ -847,21 +851,9 @@ will remove this data.  Remerge?</source>
         <source>Edit Voice Track</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Set OVERLAP Transition</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>OVERLAP</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>ListClocks</name>
-    <message>
-        <source>Log Clocks</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Filter:</source>
         <translation type="unfinished"></translation>
@@ -947,13 +939,13 @@ delete</source>
         <source>NONE</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Log Clocks - User: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListEvents</name>
-    <message>
-        <source>Log Events</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Filter:</source>
         <translation type="unfinished"></translation>
@@ -1035,6 +1027,10 @@ delete</source>
         <source>NONE</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Log Events - User: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListGrids</name>
@@ -1130,6 +1126,10 @@ Reports</source>
         <source>Manage &amp;Reports</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RDLogManager - User: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PickReportDates</name>
