@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: unity4000.cpp,v 1.5 2007/09/14 14:07:00 fredg Exp $
+//      $Id: unity4000.cpp,v 1.7.2.1 2009/04/07 11:17:11 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,7 +22,7 @@
 
 #include <stdlib.h>
 
-#include <qsqldatabase.h>
+#include <rddb.h>
 
 #include <globals.h>
 #include <unity4000.h>
@@ -32,7 +32,7 @@ Unity4000::Unity4000(RDMatrix *matrix,QObject *parent,const char *name)
   : QObject(parent,name)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   //
   // Get Matrix Parameters
@@ -48,7 +48,7 @@ Unity4000::Unity4000(RDMatrix *matrix,QObject *parent,const char *name)
                          order by NUMBER",
 			(const char *)rdstation->name(),
 			matrix->matrix());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   q->first();
   for(int i=0;i<unity_inputs;i++) {
     unity_feed.push_back(UnityFeed());
@@ -63,7 +63,7 @@ Unity4000::Unity4000(RDMatrix *matrix,QObject *parent,const char *name)
   //
   // Initialize the TTY Port
   //
-  RDTty *tty=new RDTty(rdstation->name(),matrix->port());
+  RDTty *tty=new RDTty(rdstation->name(),matrix->port(RDMatrix::Primary));
   unity_device=new RDTTYDevice();
   if(tty->active()) {
     unity_device->setName(tty->port());
@@ -84,7 +84,7 @@ Unity4000::~Unity4000()
 
 void Unity4000::processCommand(RDMacro *cmd)
 {
-  char str[16];
+  char str[256];
   char route;
   int input=cmd->arg(1).toInt()-1;
   int output=cmd->arg(2).toInt()-1;
@@ -111,13 +111,13 @@ void Unity4000::processCommand(RDMacro *cmd)
   switch(cmd->command()) {
       case RDMacro::ST:
 	if(input==-1) {
-	  sprintf(str,"MUTE A/%d\x0D",output+1);
+	  sprintf(str,"\x0DMUTE A/%d\x0D",output+1);
 	  unity_device->writeBlock(str,strlen(str));
 	}
 	else {
-	  sprintf(str,"UNMUTE A/%d\x0D",output+1);
+	  sprintf(str,"\x0DUNMUTE A/%d\x0D",output+1);
 	  unity_device->writeBlock(str,strlen(str));
-	  sprintf(str,"SETAUDIO %d %c %s\x0D",
+	  sprintf(str,"\x0DSETAUDIO %d %c %s\x0D",
 		  output+1,
 		  route,
 		  (const char *)unity_feed[input].feed());
